aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/codec/SkJpegCodec.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/codec/SkJpegCodec.h')
-rw-r--r--src/codec/SkJpegCodec.h14
1 files changed, 4 insertions, 10 deletions
diff --git a/src/codec/SkJpegCodec.h b/src/codec/SkJpegCodec.h
index 62a5bbc4cf..fac7d96075 100644
--- a/src/codec/SkJpegCodec.h
+++ b/src/codec/SkJpegCodec.h
@@ -110,19 +110,13 @@ private:
bool setOutputColorSpace(const SkImageInfo& dst);
/*
* Checks if we can scale to the requested dimensions and scales the dimensions
* if possible
*/
- bool scaleToDimensions(uint32_t width, uint32_t height);
-
- /*
- * Create the swizzler based on the encoded format
- */
- void initializeSwizzler(const SkImageInfo& dstInfo, void* dst, size_t dstRowBytes,
- const Options& options);
+ bool nativelyScaleToDimensions(uint32_t width, uint32_t height);
SkAutoTDelete<JpegDecoderMgr> fDecoderMgr;
-
+
friend class SkJpegScanlineDecoder;
typedef SkCodec INHERITED;
@@ -110,19 +110,13 @@ private:
bool setOutputColorSpace(const SkImageInfo& dst);
/*
- * Checks if we can scale to the requested dimensions and scales the dimensions
- * if possible
+ * Checks if we can natively scale to the requested dimensions and natively scales the
+ * dimensions if possible
*/